DPDK patches and discussions
 help / color / mirror / Atom feed
From: Arek Kusztal <arkadiuszx.kusztal@intel.com>
To: dev@dpdk.org
Cc: gakhil@marvell.com, roy.fan.zhang@intel.com,
	Arek Kusztal <arkadiuszx.kusztal@intel.com>
Subject: [PATCH v4 07/12] cryptodev: add public key verify option
Date: Tue, 31 May 2022 05:04:34 +0100	[thread overview]
Message-ID: <20220531040439.15862-8-arkadiuszx.kusztal@intel.com> (raw)
In-Reply-To: <20220531040439.15862-1-arkadiuszx.kusztal@intel.com>

- Added key exchange public key verify option.
For some elliptic curves public point in DH exchange
needs to be checked, if it lays on the curve.
Modular exponentiation needs certain checks as well, though
mathematically much easier.
This commit adds verify option to asym_op operations.

Signed-off-by: Arek Kusztal <arkadiuszx.kusztal@intel.com>
---
 lib/cryptodev/rte_crypto_asym.h | 11 ++++++++---
 lib/cryptodev/rte_cryptodev.c   |  3 ++-
 2 files changed, 10 insertions(+), 4 deletions(-)

diff --git a/lib/cryptodev/rte_cryptodev.c b/lib/cryptodev/rte_cryptodev.c
index cc614b0f72..42f3221052 100644
--- a/lib/cryptodev/rte_cryptodev.c
+++ b/lib/cryptodev/rte_cryptodev.c
@@ -186,7 +186,8 @@ const char *rte_crypto_asym_op_strings[] = {
 const char *rte_crypto_asym_ke_strings[] = {
 	[RTE_CRYPTO_ASYM_KE_PRIV_KEY_GENERATE] = "priv_key_generate",
 	[RTE_CRYPTO_ASYM_KE_PUB_KEY_GENERATE] = "pub_key_generate",
-	[RTE_CRYPTO_ASYM_KE_SHARED_SECRET_COMPUTE] = "sharedsecret_compute"
+	[RTE_CRYPTO_ASYM_KE_SHARED_SECRET_COMPUTE] = "sharedsecret_compute",
+	[RTE_CRYPTO_ASYM_KE_PUB_KEY_VERIFY] = "pub_ec_key_verify"
 };
 
 /**
diff --git a/lib/cryptodev/rte_crypto_asym.h b/lib/cryptodev/rte_crypto_asym.h
index f61a2ddce8..ae3ca31a89 100644
--- a/lib/cryptodev/rte_crypto_asym.h
+++ b/lib/cryptodev/rte_crypto_asym.h
@@ -130,8 +130,12 @@ enum rte_crypto_asym_ke_type {
 	/**< Private Key generation operation */
 	RTE_CRYPTO_ASYM_KE_PUB_KEY_GENERATE,
 	/**< Public Key generation operation */
-	RTE_CRYPTO_ASYM_KE_SHARED_SECRET_COMPUTE
+	RTE_CRYPTO_ASYM_KE_SHARED_SECRET_COMPUTE,
 	/**< Shared Secret compute operation */
+	RTE_CRYPTO_ASYM_KE_PUB_KEY_VERIFY
+	/**< Public Key Verification - can be used for
+	 * elliptic curve point validation.
+	 */
 };
 
 /**
@@ -455,8 +459,9 @@ struct rte_crypto_ecdh_op_param {
 	 * Output - generated public key when ke_type is
 	 * RTE_CRYPTO_ASYM_KE_PUBLIC_KEY_GENERATE.
 	 *
 	 * Input - peer's public key when ke_type is
 	 * RTE_CRYPTO_ASYM_KE_SHARED_SECRET_COMPUTE.
 	 */
 	struct rte_crypto_ec_point shared_secret;
 	/**<
@@ -455,8 +459,9 @@ struct rte_crypto_ecdh_op_param {
 	 * RTE_CRYPTO_ASYM_KE_PUBLIC_KEY_GENERATE.
 	 *
-	 * Input - peer's public key when ke_type is
-	 * RTE_CRYPTO_ASYM_KE_SHARED_SECRET_COMPUTE.
+	 * Input - peer's public key, when ke_type is one of:
+	 * RTE_CRYPTO_ASYM_KE_SHARED_SECRET_COMPUTE,
+	 * RTE_CRYPTO_ASYM_KE_EC_PUBLIC_KEY_VERIFY.
 	 */
 	struct rte_crypto_ec_point shared_secret;
-- 
2.13.6


  parent reply	other threads:[~2022-05-31  5:13 UTC|newest]

Thread overview: 34+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-05-31  4:04 [PATCH v4 00/12] cryptodev: rsa, dh, ecdh changes Arek Kusztal
2022-05-31  4:04 ` [PATCH v4 01/12] cryptodev: redefine ec group enum Arek Kusztal
2022-05-31  7:32   ` Zhang, Roy Fan
2022-05-31 12:29   ` [EXT] " Akhil Goyal
2022-05-31  4:04 ` [PATCH v4 02/12] cryptodev: separate key exchange operation enum Arek Kusztal
2022-05-31  7:34   ` Zhang, Roy Fan
2022-05-31 11:47   ` [EXT] " Akhil Goyal
2022-05-31 13:50     ` Kusztal, ArkadiuszX
2022-05-31 14:08       ` Kusztal, ArkadiuszX
2022-05-31 14:34       ` Akhil Goyal
2022-05-31  4:04 ` [PATCH v4 03/12] cryptodev: remove comment about using ephemeral key in dsa Arek Kusztal
2022-05-31  7:35   ` Zhang, Roy Fan
2022-05-31  4:04 ` [PATCH v4 04/12] cryptodev: clarify usage of private key in dh Arek Kusztal
2022-05-31  7:35   ` Zhang, Roy Fan
2022-05-31  4:04 ` [PATCH v4 05/12] cryptodev: move dh type from xform to dh op Arek Kusztal
2022-05-31  7:36   ` Zhang, Roy Fan
2022-05-31  4:04 ` [PATCH v4 06/12] cryptodev: add elliptic curve diffie hellman Arek Kusztal
2022-05-31  7:36   ` Zhang, Roy Fan
2022-05-31  8:29   ` Ray Kinsella
2022-05-31  4:04 ` Arek Kusztal [this message]
2022-05-31  7:37   ` [PATCH v4 07/12] cryptodev: add public key verify option Zhang, Roy Fan
2022-05-31  4:04 ` [PATCH v4 08/12] cryptodev: add asym op flags Arek Kusztal
2022-05-31  7:37   ` Zhang, Roy Fan
2022-05-31 11:39   ` [EXT] " Akhil Goyal
2022-05-31  4:04 ` [PATCH v4 09/12] cryptodev: clarify usage of rsa padding hash Arek Kusztal
2022-05-31  7:42   ` Zhang, Roy Fan
2022-05-31  4:04 ` [PATCH v4 10/12] cryptodev: move RSA padding into separate struct Arek Kusztal
2022-05-31  7:46   ` Zhang, Roy Fan
2022-05-31  4:04 ` [PATCH v4 11/12] cryptodev: clarify rsa verify with none padding Arek Kusztal
2022-05-31  7:47   ` Zhang, Roy Fan
2022-05-31  4:04 ` [PATCH v4 12/12] cryptodev: add salt length and optional label Arek Kusztal
2022-05-31  7:48   ` Zhang, Roy Fan
2022-05-31  7:49 ` [PATCH v4 00/12] cryptodev: rsa, dh, ecdh changes Zhang, Roy Fan
2022-05-31 11:52 ` [EXT] " Akhil Goyal

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20220531040439.15862-8-arkadiuszx.kusztal@intel.com \
    --to=arkadiuszx.kusztal@intel.com \
    --cc=dev@dpdk.org \
    --cc=gakhil@marvell.com \
    --cc=roy.fan.zhang@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).